==> jc-1.4.0.tar.gz: org/w3c/dom/bootstrap/DOMImplementationRegistry__242.h <==
// final class org.w3c.dom.bootstrap.DOMImplementationRegistry$2

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6b32cb9646ebd038 org_w3c_dom_bootstrap_DOMImplementationRegistry__242

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_w3c_dom_bootstrap_DOMImplementationRegistry__242_H_
#define _JC_org_w3c_dom_bootstrap_DOMImplementationRegistry__242_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$sub_refs	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$sub_refs;
typedef struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$sub_nonrefs	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$sub_nonrefs;
typedef struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$refs	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$refs;
typedef struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$nonrefs	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$nonrefs;
typedef struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$object	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$object;

typedef const struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$vmethods	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$vmethods;
typedef const struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$vtable	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$vtable;
typedef const struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$vtype	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$vtype;

// Constructors
extern void _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$method$run$b190d7b16d5785b8(_jc_env *, struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$object *);

// Virtual method descriptors
extern _jc_method _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$method_info$run$b190d7b16d5785b8;

// Virtual methods structure
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$vmethods {
	struct _jc_java_lang_Object$object	*(*run$b190d7b16d5785b8)(_jc_env *, struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$object *);
};

// Vtable
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$vmethods	org_w3c_dom_bootstrap_DOMImplementationRegistry__242;
};

// Vtype
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$vtype {
	_jc_type			type;
	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$refs {
    _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$sub_refs	org_w3c_dom_bootstrap_DOMImplementationRegistry__242;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$sub_nonrefs	org_w3c_dom_bootstrap_DOMImplementationRegistry__242;
};

// Object instance structure
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$object {
	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$refs	refs[0];
	_jc_word		lockword;
	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$vtype	*vtype;
	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$vtype _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_w3c_dom_bootstrap_DOMImplementationRegistry__242, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$class_object;

#endif	/* _JC_org_w3c_dom_bootstrap_DOMImplementationRegistry__242_H_ */

==> jc-1.4.6.tar.gz: org/w3c/dom/bootstrap/DOMImplementationRegistry__242.h <==
// final class org.w3c.dom.bootstrap.DOMImplementationRegistry$2

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6b32cb9646ebd038 org_w3c_dom_bootstrap_DOMImplementationRegistry__242

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_w3c_dom_bootstrap_DOMImplementationRegistry__242_H_
#define _JC_org_w3c_dom_bootstrap_DOMImplementationRegistry__242_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$sub_refs	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$sub_refs;
typedef struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$sub_nonrefs	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$sub_nonrefs;
typedef struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$refs	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$refs;
typedef struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$nonrefs	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$nonrefs;
typedef struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$object	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$object;

typedef const struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$vmethods	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$vmethods;
typedef const struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$vtable	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$vtable;
typedef const struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$vtype	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$vtype;

// Constructors
extern void _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$method$run$b190d7b16d5785b8(_jc_env *, struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$method_info$run$b190d7b16d5785b8;

// Virtual methods structure
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$vmethods {
	struct _jc_java_lang_Object$object	*(*run$b190d7b16d5785b8)(_jc_env *, struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$vmethods	org_w3c_dom_bootstrap_DOMImplementationRegistry__242;
};

// Vtype
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$vtype {
	_jc_type			type;
	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$sub_refs {
};

// Reference instance fields (object)
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$refs {
    _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$sub_refs	org_w3c_dom_bootstrap_DOMImplementationRegistry__242;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$sub_nonrefs	org_w3c_dom_bootstrap_DOMImplementationRegistry__242;
};

// Object instance structure
struct _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$object {
	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$refs	refs[0];
	_jc_word		lockword;
	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$vtype	*vtype;
	_jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$vtype _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_w3c_dom_bootstrap_DOMImplementationRegistry__242, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_w3c_dom_bootstrap_DOMImplementationRegistry__242$class_object;

#endif	/* _JC_org_w3c_dom_bootstrap_DOMImplementationRegistry__242_H_ */
